@@ -46,7 +46,7 @@ import org.herac.tuxguitar.gui.undo.undoables.track.UndoableInstrumentTrack;
 import org.herac.tuxguitar.gui.undo.undoables.track.UndoableTrackGeneric;
 import org.herac.tuxguitar.song.models.InstrumentString;
 import org.herac.tuxguitar.song.models.SongTrack;
-import org.herac.tuxguitar.song.models.TrackColor;
+import org.herac.tuxguitar.song.models.RGBColor;
 
 /**
  * @author julian
@@ -63,13 +63,14 @@ public class ChangeTrackPropertiesAction extends Action {
     private static final int MAX_NOTES = 12;
     private Shell dialog;
     private Text nameText;
-    private TrackColor trackColor;
+    private RGBColor trackColor;
     private List tempStrings;
     private TunningSpinner[] stringSpinners = new TunningSpinner[MAX_STRINGS];
     private Spinner stringCountSpinner;
+    private Combo offsetCombo;
     private int stringCount;
     private Combo instrumentCombo;
-    private Button percusionCheckBox;
+    private Button percussionCheckBox;
     
     public ChangeTrackPropertiesAction(TablatureEditor tablatureEditor) {
         super(NAME,true, tablatureEditor);
@@ -84,7 +85,7 @@ public class ChangeTrackPropertiesAction extends Action {
         SongTrackCoords trackCoords = getEditor().getTablature().getCaret().getSongTrackCoords();
         if (trackCoords != null) {
             this.stringCount = trackCoords.getTrack().getStrings().size();
-            this.trackColor = (TrackColor) trackCoords.getTrack().getColor().clone();
+            this.trackColor = (RGBColor) trackCoords.getTrack().getColor().clone();
             this.initTempStirngs(trackCoords.getTrack().getStrings());
 
             this.dialog = new Shell(shell, SWT.DIALOG_TRIM | SWT.APPLICATION_MODAL);
@@ -118,7 +119,7 @@ public class ChangeTrackPropertiesAction extends Action {
             });
 
             
-            updateTunningSpinner(!trackCoords.getTrack().isPercusionTrack());
+            updateTunningSpinner(!trackCoords.getTrack().isPercussionTrack());
             
             dialog.pack();
             dialog.open();
@@ -195,7 +196,7 @@ public class ChangeTrackPropertiesAction extends Action {
     	composite.setLayout(new GridLayout());
     	composite.setLayoutData(new GridData(SWT.FILL,SWT.FILL,true,true));
     	
-        initStringSpinner(composite);
+        initTunningData(composite,trackCoords);
         initTunningSpinners(composite);    	
     }
 
@@ -210,9 +211,9 @@ public class ChangeTrackPropertiesAction extends Action {
         }
     }
 
-    private void initStringSpinner(Composite parent) {
+    private void initTunningData(Composite parent,SongTrackCoords trackCoords) {
         Composite composite = new Composite(parent, SWT.NONE);
-        composite.setLayout(new GridLayout(2, true));    	
+        composite.setLayout(new GridLayout(4, true));    	
         composite.setLayoutData(new GridData(SWT.FILL,SWT.FILL,true,true));
         
         Label stringCountLabel = new Label(composite, SWT.NONE);
@@ -230,10 +231,21 @@ public class ChangeTrackPropertiesAction extends Action {
             public void widgetSelected(SelectionEvent e) {
                 stringCount = stringCountSpinner.getSelection();
                 setDefaultTunning();
-                updateTunningSpinner(!percusionCheckBox.getSelection());
+                updateTunningSpinner(!percussionCheckBox.getSelection());
             }
         });
 
+        
+        Label offsetLabel = new Label(composite, SWT.NONE);
+        offsetLabel.setText(TuxGuitar.getProperty("tunning.offset"));
+
+        offsetCombo = new Combo(composite, SWT.DROP_DOWN);
+        for(int i = SongTrack.MIN_OFFSET;i <= SongTrack.MAX_OFFSET;i ++){
+        	offsetCombo.add(Integer.toString(i));
+        	if(i == trackCoords.getTrack().getOffset()){
+        		offsetCombo.select(i - SongTrack.MIN_OFFSET);
+        	}
+        }               
     }
 
     private void initButtons(final Composite parent) {
@@ -285,7 +297,7 @@ public class ChangeTrackPropertiesAction extends Action {
 
         final SongTrack track = trackCoords.getTrack();
         //------------Instrument Combo-------------------------------------
-        Label instrumentLabel = new Label(composite, SWT.NULL);
+        Label instrumentLabel = new Label(composite, SWT.DROP_DOWN);
         instrumentLabel.setText(TuxGuitar.getProperty("instrument.instrument"));
         this.instrumentCombo = new Combo(composite, SWT.NULL);
         if (instruments != null) {
@@ -298,7 +310,7 @@ public class ChangeTrackPropertiesAction extends Action {
                 instrumentCombo.add(instruments[i].getName());
             }
             instrumentCombo.setText(instruments[track.getChannel().getInstrument()].getName());
-            instrumentCombo.setEnabled(!track.isPercusionTrack());
+            instrumentCombo.setEnabled(!track.isPercussionTrack());
         } else {
             instrumentCombo.setEnabled(false);
         }
@@ -306,28 +318,28 @@ public class ChangeTrackPropertiesAction extends Action {
         //--------------------Precusion CheckBox-------------------------------
         GridData gridData = new GridData();
         gridData.horizontalSpan = 2;
-        this.percusionCheckBox = new Button(composite, SWT.CHECK);
-        percusionCheckBox.setText(TuxGuitar.getProperty("instrument.percusion-track"));
-        percusionCheckBox.setLayoutData(gridData);
+        this.percussionCheckBox = new Button(composite, SWT.CHECK);
+        percussionCheckBox.setText(TuxGuitar.getProperty("instrument.percussion-track"));
+        percussionCheckBox.setLayoutData(gridData);
         if (instruments != null) {
-            percusionCheckBox.setSelection(track.isPercusionTrack());
-            percusionCheckBox.addSelectionListener(new SelectionAdapter() {
+            percussionCheckBox.setSelection(track.isPercussionTrack());
+            percussionCheckBox.addSelectionListener(new SelectionAdapter() {
                 public void widgetSelected(SelectionEvent arg0) {
-                    instrumentCombo.setEnabled(!percusionCheckBox.getSelection());
+                    instrumentCombo.setEnabled(!percussionCheckBox.getSelection());
                     
                     setDefaultTunning();
-                    updateTunningSpinner(!percusionCheckBox.getSelection());                                            
+                    updateTunningSpinner(!percussionCheckBox.getSelection());                                            
                 }
             });
         } else {
-            percusionCheckBox.setEnabled(false);
+            percussionCheckBox.setEnabled(false);
         }
         //-----------------------------------------------------------
     }
 
     private Instrument[] getInstruments() {
         Instrument[] instruments = null;
-        Soundbank sb = getEditor().getSongManager().getPlayer().getDefaultSoundbank();
+        Soundbank sb = getEditor().getSongManager().getPlayer().getSoundbank();
         if (sb != null) {
             instruments = sb.getInstruments();
         }
@@ -338,7 +350,7 @@ public class ChangeTrackPropertiesAction extends Action {
         SongTrackCoords trackCoords = getEditor().getTablature().getCaret().getSongTrackCoords();
         
         String trackName = this.nameText.getText();
-        TrackColor trakColor = this.trackColor;
+        RGBColor trakColor = this.trackColor;
         
         int stringNumber = 1;
         List strings = new ArrayList();
@@ -346,13 +358,13 @@ public class ChangeTrackPropertiesAction extends Action {
             strings.add(new InstrumentString(stringNumber, stringSpinners[i].getSelection()));
             stringNumber++;
         }
-        
+        int offset = SongTrack.MIN_OFFSET + offsetCombo.getSelectionIndex();
         int instrument = instrumentCombo.getSelectionIndex();
-        boolean percusion = percusionCheckBox.getSelection();
+        boolean percussion = percussionCheckBox.getSelection();
         
-        boolean infoChanges = hasInfoChanges(trackCoords,trackName,trackColor);
+        boolean infoChanges = hasInfoChanges(trackCoords,trackName,trackColor,offset);
         boolean tunningChanges = hasTunningChanges(trackCoords,strings);
-        boolean instrumentChanges = hasInstrumentChanges(trackCoords,instrument,percusion);
+        boolean instrumentChanges = hasInstrumentChanges(trackCoords,instrument,percussion);
         
         if(infoChanges || tunningChanges || instrumentChanges){
         	JoinedUndoable undoable = new JoinedUndoable();
@@ -368,7 +380,7 @@ public class ChangeTrackPropertiesAction extends Action {
         		if(!tunningChanges){
         			undoableInfo = UndoableInfoTrack.startUndo(trackCoords.getTrack());
         		}
-        		getEditor().getSongManager().getTrackManager().changeInfo(trackCoords.getTrack(),trackName,trackColor);
+        		getEditor().getSongManager().getTrackManager().changeInfo(trackCoords.getTrack(),trackName,trackColor,offset);
         		if(!tunningChanges){
         			undoable.addUndoableEdit(undoableInfo.endUndo(trackCoords.getTrack()));
         		}
@@ -383,7 +395,7 @@ public class ChangeTrackPropertiesAction extends Action {
         		if(!tunningChanges){
         			undoableInstrument = UndoableInstrumentTrack.startUndo(trackCoords.getTrack());
         		}        	
-        		getEditor().getSongManager().getTrackManager().changeInstrument(trackCoords.getTrack(),instrument,percusion);
+        		getEditor().getSongManager().getTrackManager().changeInstrument(trackCoords.getTrack(),instrument,percussion);
         		if(!tunningChanges){
         			undoable.addUndoableEdit(undoableInstrument.endUndo(trackCoords.getTrack()));
         		}
@@ -396,13 +408,16 @@ public class ChangeTrackPropertiesAction extends Action {
         }
     }
     
-    private boolean hasInfoChanges(SongTrackCoords trackCoords,String name,TrackColor color){
+    private boolean hasInfoChanges(SongTrackCoords trackCoords,String name,RGBColor color,int offset){
     	if(!name.equals(trackCoords.getTrack().getName())){
     		return true;
     	}
     	if(!color.isEqual(trackCoords.getTrack().getColor())){
     		return true;
     	}    	
+    	if(offset != trackCoords.getTrack().getOffset()){
+    		return true;
+    	}
     	return false;
     }
     
@@ -428,15 +443,15 @@ public class ChangeTrackPropertiesAction extends Action {
     	}
     	return false;
     }
-
-    private boolean hasInstrumentChanges(SongTrackCoords trackCoords,int instrument,boolean percusion){
+    
+    private boolean hasInstrumentChanges(SongTrackCoords trackCoords,int instrument,boolean percussion){
     	if(instrument < 0){
     		return false;
     	}
     	if(trackCoords.getTrack().getChannel().getInstrument() != instrument){
     		return true;
     	}
-    	if(trackCoords.getTrack().isPercusionTrack() != percusion){
+    	if(trackCoords.getTrack().isPercussionTrack() != percussion){
     		return true;
     	}
     	return false;
@@ -469,7 +484,7 @@ public class ChangeTrackPropertiesAction extends Action {
     private void setDefaultTunning() {
         this.tempStrings.clear();
 
-        if (percusionCheckBox.getSelection()) {
+        if (percussionCheckBox.getSelection()) {
             for (int i = 1; i <= stringCount; i++) {
                 this.tempStrings.add(new InstrumentString(i, 0));
             }
