@@ -19,7 +19,7 @@ import org.herac.tuxguitar.song.models.Duration;
  */
 public interface MeasureComponent {    
 	public Component getComponent();
-	public void update();
+	public void update(ViewLayout layout);
     public void paint(ViewLayout layout,GC gc, int fromX, int fromY);
     public void setDuration(Duration duration);
     public Duration getDuration();
