@@ -133,16 +133,12 @@ public class NoteCoords implements MeasureComponent {
     private ScoreBeatHelper scoreBeatHelper;
     
     private Image bendImage;    
-     
-    
-    private int span;
-    
-    private boolean shouldSetSpan;
     
     private int pointX;
     
     private int pointY;
     
+    private int scorePosY;
     
     public NoteCoords(Tablature tablature, SongTrackCoords trackCoords, MeasureCoords meassureCoords, Note note, int posX, int posY) {
         this.tablature = tablature;
@@ -158,17 +154,15 @@ public class NoteCoords implements MeasureComponent {
     /**
      * Actualiza los valores para dibujar
      */
-    public void update() {
-    	this.shouldSetSpan = true;    	
-    	
+    public void update(ViewLayout layout) {    	
         this.joinedType = JOINED_TYPE_NONE_RIGHT;
         this.joinedGreaterThanQuarter = false;
         this.durationCoords.setNote1(this);
         this.durationCoords.setNote2(this);
-        this.durationCoords.setEighthY(meassureCoords.getHeight() + 25);
-        this.durationCoords.setSixteenthY(meassureCoords.getHeight() + 20);
-        this.durationCoords.setThirtySecondY(meassureCoords.getHeight() + 15);
-        this.durationCoords.setSixtyFourthY(meassureCoords.getHeight() + 10);
+        this.durationCoords.setEighthY(meassureCoords.getTabHeight() + 25);
+        this.durationCoords.setSixteenthY(meassureCoords.getTabHeight() + 20);
+        this.durationCoords.setThirtySecondY(meassureCoords.getTabHeight() + 15);
+        this.durationCoords.setSixtyFourthY(meassureCoords.getTabHeight() + 10);
 
         boolean noteJoined = false;
         boolean withPrev = false;
@@ -221,6 +215,7 @@ public class NoteCoords implements MeasureComponent {
             this.joinedType = JOINED_TYPE_NONE_LEFT;            
         }
 
+        this.scorePosY = scoreBeatHelper.getY1(layout,this,meassureCoords.getMeasure().getKeySignature(),meassureCoords.getMeasure().getClef());
         this.updateUsedStrings();
         this.updateEffects();                
     }
@@ -257,13 +252,10 @@ public class NoteCoords implements MeasureComponent {
     /**
      * Pinta la nota
      */
-    public void paint(ViewLayout layout,GC gc, int fromX, int fromY) {    	
+    public void paint(ViewLayout layout,GC gc, int fromX, int fromY) {    	    	
         int x = fromX + getPosX() + getSpan();
         int y = fromY + getPosY();
         this.pointX = x;
-        
-        layout.setNoteStyle(gc);
-        
 
     	//SCORE NOTE
     	if(layout.isScoreEnabled()){        		
@@ -272,8 +264,10 @@ public class NoteCoords implements MeasureComponent {
     	}
         
         if(layout.isPlayModeEnabled() && isPlaying()){
-            gc.setForeground(this.tablature.getDisplay().getSystemColor(SWT.COLOR_RED));
-        } 
+        	layout.setPlayNoteColor(gc);
+        }else{
+        	layout.setTabNoteColor(gc);
+        }
         if (getNote().isTiedNote()) {   
         	if(!layout.isScoreEnabled()){     
         		NoteCoords noteForTie = getNoteForTie();
@@ -295,11 +289,13 @@ public class NoteCoords implements MeasureComponent {
         
                         
         if(layout.isPlayModeEnabled() && isPlaying()){
-            gc.drawString(">", (fromX + getPosX() + getSpan()) - 2,fromY +  this.meassureCoords.getHeight() + 50);   
-            gc.setForeground(tablature.getDisplay().getSystemColor(SWT.COLOR_BLACK));
+        	//gc.drawString(">", (fromX + getPosX() + getSpan()) - 2,fromY +  this.meassureCoords.getTabHeight() + 50);
+        	int span = (meassureCoords.getScoreSpan() > 0 )?meassureCoords.getScoreSpan() + 10:50;
+        	gc.drawString(">", (fromX + getPosX() + getSpan()) - 2,fromY +  meassureCoords.getTabHeight() + span);
+            layout.setTabNoteColor(gc);
         }
                 
-        if(layout.isScoreEnabled()){
+        if(layout.isScoreEnabled()){        	
         	paintEffects(gc,fromX,fromY + layout.getScoreSpan());
         }else{
         	paintDuration(layout,gc, fromX, fromY);
@@ -357,7 +353,8 @@ public class NoteCoords implements MeasureComponent {
      */
     private void paintDuration(ViewLayout layout,GC gc, int fromX, int fromY) {
         int x = fromX + getPosX() + getSpan();
-        int y2 = fromY + meassureCoords.getHeight() + 25;
+        int y2 = fromY + meassureCoords.getTabHeight() + 25;
+        //int y2 = fromY + meassureCoords.getHeight() + 25;
 
         paintVerticalLine(layout,gc, fromX, fromY);
 
@@ -387,14 +384,17 @@ public class NoteCoords implements MeasureComponent {
                     int stringPosition = fromY + (stringSpan * (i + 1));
                     int y1 = stringPosition - (stringSpan / 2);
                     int y2 = stringPosition + (stringSpan / 2);
-                	
+                	y2 = ((y2 - y1 < stringSpan)?y2 + 1:y2);
+                    
                     gc.drawLine(x, y1, x, y2);
                 }
             }
-            int y = fromY + meassureCoords.getHeight() + (stringSpan / 2);
+            //int y = fromY + meassureCoords.getHeight() + (stringSpan / 2);
+            int y = fromY + meassureCoords.getTabHeight() + (stringSpan / 2);
             gc.drawLine(x, y, x, y + 19);
         } else if (note.getDuration().getValue() == Duration.HALF) {
-            int y = fromY + meassureCoords.getHeight() + (stringSpan / 2) + 9;
+            int y = fromY + meassureCoords.getTabHeight() + (stringSpan / 2) + 9;
+            //int y = fromY + meassureCoords.getHeight() + (stringSpan / 2) + 9;
             gc.drawLine(x, y, x, y + 10);
         }
     }
@@ -480,7 +480,8 @@ public class NoteCoords implements MeasureComponent {
             y += this.durationCoords.getSixtyFourthY() - 5;
             break;
         default:
-            y += meassureCoords.getHeight() + 22;
+        	y += meassureCoords.getTabHeight() + 22;
+            //y += meassureCoords.getHeight() + 22;
         	x = fromX + getPosX() + 4  + getSpan();
             break;
         }
@@ -535,9 +536,11 @@ public class NoteCoords implements MeasureComponent {
                         if(nextComponent != null){                 
                             NoteCoords nextNote = (NoteCoords)nextComponent;
                             int nextX = nextNote.getPosX() + nextFromX + meassureCoords.getSpanForComponent(nextNote);                        
-                            gc.drawArc(x,y, (nextX - x),-5,45,90);
+                            gc.drawArc(x + 5,y - 5, (nextX - 6 - (x + 5)),15,45,90);
+                            //gc.drawArc(x,y, (nextX - x),-5,45,90);                            
                         }else{
-                            gc.drawArc(x,y,20,-5,45,90);
+                        	gc.drawArc(x + 5,y - 5,10,15,45,90);
+                            //gc.drawArc(x,y,20,-5,45,90);
                         }
                     }
                 
@@ -571,24 +574,37 @@ public class NoteCoords implements MeasureComponent {
     	int scoreLineSpan = layout.getScoreLineSpan();
     	
     	int x = fromX + getPosX() + getSpan();    	
-		int y1 = fromY + scoreBeatHelper.getY1(layout,this,key,clef);		
+    	int y1 = fromY + getScorePosY();
+		//int y1 = fromY + scoreBeatHelper.getY1(layout,this,key,clef);		
 		
 		//----------lineas extras----------------------------------
 		if(y1 < (fromY + scoreLineSpan)){
+			gc.setForeground(tablature.getDisplay().getSystemColor(SWT.COLOR_BLACK));
 			for(int i = (fromY + scoreLineSpan);i > y1;i -= scoreLineSpan){
 				gc.drawLine(x - 4,i,x + 12,i);
 			}
 		}else if(y1 > (fromY + (scoreLineSpan * 5))){
+			gc.setForeground(tablature.getDisplay().getSystemColor(SWT.COLOR_BLACK));
 			for(int i = (fromY +(scoreLineSpan * 5));i < y1;i += scoreLineSpan){
 				gc.drawLine(x - 4,(i + scoreLineSpan),x + 12,(i + scoreLineSpan));
 			}			
 		}
+		
+		//-------------background--------------------------------------
+		boolean playMode = (layout.isPlayModeEnabled() && isPlaying());		
+        if(playMode){
+        	layout.setPlayNoteColor(gc);
+        }else{
+        	layout.setScoreNoteColor(gc);
+        }
+        
 		//----------ligadura---------------------------------------
         if (getNote().isTiedNote()) {        
         	NoteCoords noteForTie = getNoteForTie();
         	if (noteForTie != null && noteForTie.isAtSameLine(fromY)) {               		        	
         		int ligadureX = noteForTie.getPointX();
-        		int ligadureY = noteForTie.getLastFromY() + scoreBeatHelper.getY1(layout,this,key,clef);
+        		int ligadureY = noteForTie.getLastFromY() + getScorePosY();
+        		//int ligadureY = noteForTie.getLastFromY() + scoreBeatHelper.getY1(layout,this,key,clef);
 
         		gc.drawArc(ligadureX + 3, ligadureY - 3, (x - ligadureX), 35, 45, 90);
         	}else{        		
@@ -617,22 +633,18 @@ public class NoteCoords implements MeasureComponent {
 			}			
 		}
 		//----------fin sostenido--------------------------------------
-		boolean playMode = (layout.isPlayModeEnabled() && isPlaying());
+		int size = (layout.getScoreLineSpan() - 2);
 		
-        if(playMode){
-            gc.setForeground(this.tablature.getDisplay().getSystemColor(SWT.COLOR_RED));
-        } 		
-		
-		gc.drawOval(x,y1 + 1,8,8);
+		gc.drawOval(x,y1 + 1,size,size);
 		//relleno el circulo
 		if(note.getDuration().getValue() >= Duration.QUARTER){
-	        gc.setBackground((playMode)?tablature.getDisplay().getSystemColor(SWT.COLOR_RED):tablature.getDisplay().getSystemColor(SWT.COLOR_BLACK));
-			gc.fillOval(x,y1 + 1,8,8);
+			gc.setBackground(gc.getForeground());
+			gc.fillOval(x,y1 + 1,size,size);
 			gc.setBackground(tablature.getDisplay().getSystemColor(SWT.COLOR_WHITE));
 		}
 		
         if(playMode){
-            gc.setForeground(this.tablature.getDisplay().getSystemColor(SWT.COLOR_BLACK));
+        	layout.setScoreNoteColor(gc);
         } 		
         
 		  
@@ -647,15 +659,18 @@ public class NoteCoords implements MeasureComponent {
         }        
         //TUPLETO
         if (!note.getDuration().getTupleto().isEqual(Duration.NO_TUPLETO)) {
-            gc.drawString(Integer.toString(note.getDuration().getTupleto().getEnters()), x + 2, fromY + 95);
+        	gc.drawString(Integer.toString(note.getDuration().getTupleto().getEnters()), x + 1, fromY + layout.getScoreSpan() - 12);
+            //gc.drawString(Integer.toString(note.getDuration().getTupleto().getEnters()), x + 2, fromY + 95);
         }        
         
 		//dibujo el pie
 		if(note.getDuration().getValue() >= Duration.HALF){
 	    	y1 += 5;
 			if(scoreBeatHelper.getDirection() == ScoreBeatHelper.DIRECTION_UP){
-	    		x += 9;
-	    		fromX += 9;
+	    		x += size + 1;
+	    		fromX += size + 1;
+	    		//x += 9;
+	    		//fromX += 9;
 	    	}
 			
 	        int y2 = fromY + scoreBeatHelper.getY2(layout,getPosX() + getSpan(),key,clef);
@@ -838,12 +853,8 @@ public class NoteCoords implements MeasureComponent {
     	return (!meassureCoords.isOutOfBounds() && (getLastFromY() == y));   
     }
     
-    public int getSpan(){    	
-    	if(this.shouldSetSpan){
-    		this.span = meassureCoords.getSpanForComponent(this);
-    		this.shouldSetSpan = false;    		
-    	}
-        return this.span;
+    public int getSpan(){
+        return meassureCoords.getSpanForComponent(this);
     }
     
     public int getPointX(){
@@ -868,6 +879,10 @@ public class NoteCoords implements MeasureComponent {
 	public Component getComponent() {
 		return getNote();
 	}
+
+	public int getScorePosY() {
+		return scorePosY;
+	}
     
 
 }
\ No newline at end of file
