@@ -37,7 +37,7 @@ import org.herac.tuxguitar.gui.tab.MeasureCoords;
 import org.herac.tuxguitar.gui.tab.SongTrackCoords;
 import org.herac.tuxguitar.song.models.SongChannel;
 import org.herac.tuxguitar.song.models.SongTrack;
-import org.herac.tuxguitar.song.models.TrackColor;
+import org.herac.tuxguitar.song.models.RGBColor;
 
 
 public class SongTableInfo extends Composite{    
@@ -161,7 +161,8 @@ public class SongTableInfo extends Composite{
 					if(measureIndex >= 0){
 						MeasureCoords measure = (MeasureCoords)track.getMeasuresCoords().get(measureIndex);
 						editor.getTablature().getCaret().moveTo(track,measure,measure.getFirstComponent());
-						TuxGuitar.instance().getTransport().gotoMeasure(measure.getMeasure());
+						editor.getTablature().getCaret().setChanges(true);
+						//TuxGuitar.instance().getTransport().gotoMeasure(measure.getMeasure());
 						TuxGuitar.instance().redraw();
 					}						
 				}
@@ -183,8 +184,12 @@ public class SongTableInfo extends Composite{
 			final SongTrackCoords track = (SongTrackCoords)tracks.get(i);
 			String number = Long.toString(track.getTrack().getNumber());
 			String name = track.getTrack().getName();
-			String instrument = editor.getSongManager().getInstrumentName(track.getTrack().getChannel().getInstrument());
-	    	
+			String instrument = "";
+			if(track.getTrack().isPercussionTrack()){
+				instrument = TuxGuitar.getProperty("track.name.default-percussion-name");
+			}else{
+				instrument = editor.getSongManager().getInstrumentName(track.getTrack().getChannel().getInstrument());
+			}
 			updateTableItems(i,new String[] {number,name,instrument},track);
 	    }
 		this.updateItemBackgrounds();
@@ -341,23 +346,28 @@ public class SongTableInfo extends Composite{
 			}
 			y = fromY + (controlBounds.y - firstTableItemY);
 			
+			//gc.setForeground(getDisplay().getSystemColor(SWT.COLOR_WHITE));
 			gc.setBackground(getDisplay().getSystemColor(SWT.COLOR_GRAY));
 			gc.fillRectangle(0,y,width,itemSpan - 1);
 
-			TrackColor trackColor = track.getTrack().getColor();
-			Color color = new Color(getDisplay(),trackColor.getR(),trackColor.getG(),trackColor.getB());
-			gc.setBackground(color);
-
+			RGBColor rgb = track.getTrack().getColor();
+			Color trackColor = new Color(getDisplay(),rgb.getR(),rgb.getG(),rgb.getB());
+			gc.setBackground(trackColor);
+			gc.setForeground(trackColor);
+			
 			List measures = track.getMeasuresCoords();
 			this.measureLength = measures.size();
 			for(int j = 0;j < measureLength;j++){
-				MeasureCoords measure = (MeasureCoords)measures.get(j);
-				gc.fillRectangle(x,y,itemSpan - 1,itemSpan - 1);
-				
+				MeasureCoords measure = (MeasureCoords)measures.get(j);				
+				if(measure.getMeasure().getNotes().isEmpty()){
+					gc.drawRectangle(x,y,itemSpan -2 ,itemSpan - 2);
+				}else{
+					gc.fillRectangle(x,y,itemSpan - 1,itemSpan - 1);
+				}
 				if((playing && measure.isPlaying()) || (!playing && measure.hasCaret())){
 					gc.setBackground(getDisplay().getSystemColor(SWT.COLOR_BLACK));
 					gc.fillRectangle(x + 4,y + 4,itemSpan - 9,itemSpan - 9);
-					gc.setBackground(color);
+					gc.setBackground(trackColor);
 					this.lasPlayedMeasure = measure;
 				}
 				
@@ -366,7 +376,7 @@ public class SongTableInfo extends Composite{
 			x = fromX;
 			y += itemSpan;
 			
-			color.dispose();		
+			trackColor.dispose();		
 		}
 		gc.setBackground(getDisplay().getSystemColor(SWT.COLOR_BLACK));
 		
@@ -611,6 +621,5 @@ public class SongTableInfo extends Composite{
 		for(int i = 0;i < BACKGROUNDS.length;i++){
 			BACKGROUNDS[i].dispose();	
 		}
-		
 	}
 }
