@@ -11,7 +11,9 @@ import java.util.List;
 import org.herac.tuxguitar.song.models.BendEffect;
 import org.herac.tuxguitar.song.models.Duration;
 import org.herac.tuxguitar.song.models.InstrumentString;
+import org.herac.tuxguitar.song.models.Marker;
 import org.herac.tuxguitar.song.models.Measure;
+import org.herac.tuxguitar.song.models.MeasureHeader;
 import org.herac.tuxguitar.song.models.Note;
 import org.herac.tuxguitar.song.models.NoteEffect;
 import org.herac.tuxguitar.song.models.Song;
@@ -19,18 +21,20 @@ import org.herac.tuxguitar.song.models.SongChannel;
 import org.herac.tuxguitar.song.models.SongTrack;
 import org.herac.tuxguitar.song.models.Tempo;
 import org.herac.tuxguitar.song.models.TimeSignature;
-import org.herac.tuxguitar.song.models.TrackColor;
+import org.herac.tuxguitar.song.models.RGBColor;
 
 public class GP4InputStream extends InputStream {
     private static final String supportedVersions[] = { "FICHIER GUITAR PRO v4.00", "FICHIER GUITAR PRO v4.06", "FICHIER GUITAR PRO L4.06" };
-    private String version;
     private InputStream inputStream;
-    private int offset;
+    private String version;
+    private int tripletFeel;
+    
+    //private int offset;
 
     public GP4InputStream(InputStream inputStream) {
         super();
         this.inputStream = inputStream;
-        this.offset = 0;
+        //this.offset = 0;
     }
 
     public GP4InputStream(String fileName) throws FileNotFoundException {
@@ -42,7 +46,7 @@ public class GP4InputStream extends InputStream {
     }
 
     public int read() throws IOException {
-        this.offset++;
+        //this.offset++;
         return this.inputStream.read();
     }
 
@@ -105,8 +109,9 @@ public class GP4InputStream extends InputStream {
             note += "\n";
         }
 
-        boolean tripletFeel = readBoolean();
-
+        //boolean tripletFeel = readBoolean();
+        this.tripletFeel = ((readBoolean())?MeasureHeader.TRIPLET_FEEL_EIGHTH:MeasureHeader.TRIPLET_FEEL_NONE);
+        
         int trackNumber = readInt();
         for (int i = 0; i < 5; i++) {
             int measureNumber = readInt();
@@ -142,11 +147,11 @@ public class GP4InputStream extends InputStream {
         int numberOfMeasures = readInt();
         int numberOfTracks = readInt();
 
-        List measures = new ArrayList();
+        List headers = new ArrayList();
         if (numberOfMeasures > 0) {
             for (int i = 0; i < numberOfMeasures; i++) {
-                Measure measure = createMeasure((i + 1),timeSignature);
-                measures.add(measure);
+                MeasureHeader header = createMeasureHeader((i + 1),timeSignature);
+                headers.add(header);
             }
         }
 
@@ -157,30 +162,21 @@ public class GP4InputStream extends InputStream {
 
         long nextMeasureStart = 1000;
         for (int i = 0; i < numberOfMeasures; i++) {
-            Measure currMeasure = (Measure) measures.get(i);
-            Measure lastMeasure = null;
-            currMeasure.setStart(nextMeasureStart);
+            MeasureHeader currHeader = (MeasureHeader) headers.get(i);
+            Tempo tempo = new Tempo(tempoValue);
+            currHeader.setStart(nextMeasureStart);
             for (int j = 0; j < numberOfTracks; j++) {
                 SongTrack track = (SongTrack) tracks.get(j);
-                Measure measure = (Measure) currMeasure.clone();
-
-                Tempo tempo = new Tempo(tempoValue);
+                Measure measure = new Measure(currHeader,new ArrayList(),new ArrayList(),1,0);
                 addMeasureComponents(track.getStrings(), measure, track.getMeasures(), tempo);
-                
-                //checkeo que el tempo coincida
-                if(lastMeasure != null && lastMeasure.getTempo().getValue() != tempo.getValue()){
-                	measure.setTempo((Tempo)lastMeasure.getTempo().clone());      
-                }else{
-                	measure.setTempo(tempo);       
-                }
-                lastMeasure = measure;                                       
-                
+                currHeader.setTempo(tempo);      
                 track.getMeasures().add(measure);
             }
-            nextMeasureStart += currMeasure.getLength();
+            tempoValue = tempo.getValue();
+            nextMeasureStart += currHeader.getLength();
         }
 
-        return new Song(title,interpret,album,songAuthor,tracks,Song.MAX_VOLUME);
+        return new Song(title,interpret,album,songAuthor,tracks,headers,Song.MAX_VOLUME);
     }
 
     private long addNotes(long start, List notes, List trackStrings, List currTrackMeasures, Tempo tempo) throws IOException,
@@ -271,25 +267,25 @@ public class GP4InputStream extends InputStream {
 
     private List getPlayedStrings(int stringsPlayed, List trackStrings) {
         List strings = new ArrayList();
-        if ((stringsPlayed & (1 << 0)) != 0) {
+        if ((stringsPlayed & (1 << 0)) != 0 && trackStrings.size() > 6) {
             strings.add(((InstrumentString) trackStrings.get(6)).clone());
         }
-        if ((stringsPlayed & (1 << 1)) != 0) {
+        if ((stringsPlayed & (1 << 1)) != 0 && trackStrings.size() > 5) {
             strings.add(((InstrumentString) trackStrings.get(5)).clone());
         }
-        if ((stringsPlayed & (1 << 2)) != 0) {
+        if ((stringsPlayed & (1 << 2)) != 0 && trackStrings.size() > 4) {
             strings.add(((InstrumentString) trackStrings.get(4)).clone());
         }
-        if ((stringsPlayed & (1 << 3)) != 0) {
+        if ((stringsPlayed & (1 << 3)) != 0 && trackStrings.size() > 3) {
             strings.add(((InstrumentString) trackStrings.get(3)).clone());
         }
-        if ((stringsPlayed & (1 << 4)) != 0) {
+        if ((stringsPlayed & (1 << 4)) != 0 && trackStrings.size() > 2) {
             strings.add(((InstrumentString) trackStrings.get(2)).clone());
         }
-        if ((stringsPlayed & (1 << 5)) != 0) {
+        if ((stringsPlayed & (1 << 5)) != 0 && trackStrings.size() > 1) {
             strings.add(((InstrumentString) trackStrings.get(1)).clone());
         }
-        if ((stringsPlayed & (1 << 6)) != 0) {
+        if ((stringsPlayed & (1 << 6)) != 0 && trackStrings.size() > 0) {
             strings.add(((InstrumentString) trackStrings.get(0)).clone());
         }
         return strings;
@@ -320,6 +316,10 @@ public class GP4InputStream extends InputStream {
             duration = new Duration(Duration.SIXTY_FOURTH);
             break;
         }
+        if(duration == null){
+        	duration = new Duration(Duration.QUARTER);
+        	System.err.println("Incorrect Duration. Forcing duration Quarter as Default.");
+        }        
         return duration;
     }
 
@@ -354,13 +354,13 @@ public class GP4InputStream extends InputStream {
         return (byte) read();
     }
 
-    private TrackColor readColor() throws IOException {
+    private RGBColor readColor() throws IOException {
         int r = readUnsignedByte();
         int g = readUnsignedByte();
         int b = readUnsignedByte();
         read();
         
-        return new TrackColor(r,g,b);
+        return new RGBColor(r,g,b);
     }
 
     private int readInt() throws IOException {
@@ -373,12 +373,14 @@ public class GP4InputStream extends InputStream {
         return integer;
     }
 
-    private void readMarker() throws IOException {
+    private Marker readMarker(int measure) throws IOException {
         String name = readStringIntegerPlusOne();
-        readColor();
+        RGBColor color = readColor();
+        
+        return new Marker(measure,name,color);
     }
 
-    private Measure createMeasure(int number,TimeSignature currTimeSignature) throws IOException {
+    private MeasureHeader createMeasureHeader(int number,TimeSignature currTimeSignature) throws IOException {
         int header = readUnsignedByte();
 
         int numerator = 0;
@@ -403,8 +405,9 @@ public class GP4InputStream extends InputStream {
             NumberOfAlternateEnding = readByte();
         }
 
+        Marker marker = null;
         if ((header & 0x20) != 0) {
-            readMarker();
+        	marker = readMarker(number);
         }
 
         if ((header & 0x40) != 0) {
@@ -423,9 +426,8 @@ public class GP4InputStream extends InputStream {
         if (denominator > 0) {
             currTimeSignature.setDenominator(new Duration(denominator));
         }
-
-        return new Measure(number,0, new ArrayList(), new ArrayList(), (TimeSignature) currTimeSignature.clone(), new Tempo(120),1,0, repeatStart,
-                numberOfRepetitions);
+        
+        return new MeasureHeader(number,0,(TimeSignature) currTimeSignature.clone(), new Tempo(120),marker,tripletFeel,repeatStart,numberOfRepetitions);
     }
 
     private void addMeasureComponents(List trackStrings, Measure measure, List currTrackMeasures, Tempo tempo) throws IOException,
@@ -490,19 +492,18 @@ public class GP4InputStream extends InputStream {
     }
 
     private String readStringByte(int expectedLength) throws IOException {
-        byte[] b;
-        String str;
+        byte[] bytes;
         int realLength = readUnsignedByte();
 
         if (expectedLength != 0) {
-            b = new byte[expectedLength];
+        	bytes = new byte[expectedLength];
         } else {
-            b = new byte[realLength];
+        	bytes = new byte[realLength];
         }
-
-        read(b);
-        str = new String(b, 0, realLength);
-        return str;
+        read(bytes);
+        
+        realLength = (realLength >= 0)?realLength:expectedLength;
+        return new String(bytes, 0, realLength); 
     }
 
     private String readStringInteger() throws IOException {
@@ -564,9 +565,9 @@ public class GP4InputStream extends InputStream {
 
         int capo = readInt();
 
-        TrackColor color = readColor();
+        RGBColor color = readColor();
         
-        return new SongTrack(number,name,parseChannel(channels,channelIndex,effects), new ArrayList(), strings,color);
+        return new SongTrack(number,name,parseChannel(channels,channelIndex,effects), new ArrayList(), strings,0,color);
     }
     
     private SongChannel parseChannel(List channels, int channelIndex,int effectChannel) {
@@ -624,68 +625,73 @@ public class GP4InputStream extends InputStream {
         return (String.valueOf(nameC, 0, max));
     }
 
-    private void readChordDiagram() throws IOException, GPFormatException {
-        int header;
-        long aux;
-        long skip;
-        int i;
-
-        header = readUnsignedByte();
+    private void readChordDiagram() throws IOException, GPFormatException {        
+        int header = readUnsignedByte();
 
         if ((header & 0x01) == 0) {
-            throw new GPFormatException("Cannot Read Chord Diagram");
+            String name = readStringIntegerPlusOne();
+            int base = readInt();
+
+            if (base != 0) {
+                for (int i = 0; i < 6; i++) {
+                    int fret = readInt();
+                }
+            }
+            //new GPFormatException("Cannot Read Chord Diagram");         
+        }else{
+
+        	boolean sharp = readBoolean();
+
+        	this.skip(3);
+
+        	readRoot();
+
+        	readChordType();
+
+        	int nineElevenThirteen = readUnsignedByte();
+
+        	int bass = readInt();
+
+        	readTonalityType(4);
+
+        	int addedNote = readUnsignedByte();
+
+        	String name = readChordName();
+
+        	this.skip(2);
+
+        	readTonalityType(1);
+
+        	readTonalityType(1);
+
+        	readTonalityType(1);
+
+        	int baseFret = readInt();
+
+        	for (int i = 1; i <= 7; i++) {
+        		int fret = readInt();
+        	}
+
+        	int numBarres = readUnsignedByte();
+
+        	for (int i = 1; i <= 5; i++) {
+        		int fretOfBarre = readUnsignedByte();
+        	}
+        	for (int i = 1; i <= 5; i++) {
+        		int barreStart = readUnsignedByte();
+        	}
+        	for (int i = 1; i <= 5; i++) {
+        		int barreEnd = readUnsignedByte();
+        	}
+
+            this.skip(8);
+        	
+            for (int i = 1; i <= 7; i++) {
+        		int fingering = readByte();
+        	}
+        	
+            boolean chordFingeringDisplayed = readBoolean();
         }
-
-        boolean sharp = readBoolean();
-
-        this.skip(3);
-
-        readRoot();
-
-        readChordType();
-
-        int nineElevenThirteen = readUnsignedByte();
-
-        int bass = readInt();
-
-        readTonalityType(4);
-
-        int addedNote = readUnsignedByte();
-
-        String name = readChordName();
-
-        this.skip(2);
-
-        readTonalityType(1);
-
-        readTonalityType(1);
-
-        readTonalityType(1);
-
-        int baseFret = readInt();
-
-        for (i = 1; i <= 7; i++) {
-            int fret = readInt();
-        }
-
-        int numBarres = readUnsignedByte();
-
-        for (i = 1; i <= 5; i++) {
-            int fretOfBarre = readUnsignedByte();
-        }
-        for (i = 1; i <= 5; i++) {
-            int barreStart = readUnsignedByte();
-        }
-        for (i = 1; i <= 5; i++) {
-            int barreEnd = readUnsignedByte();
-        }
-
-        aux = this.skip(8);
-
-        for (i = 1; i <= 7; i++) {
-            int fingering = readByte();
-        }
-        boolean chordFingeringDisplayed = readBoolean();
     }
 
     private void readGraceNote() throws IOException {
@@ -786,7 +792,7 @@ public class GP4InputStream extends InputStream {
             case 3:
                 break;
             default:
-                throw new IOException();
+                //throw new IOException();
             }
         }
 
