@@ -13,7 +13,9 @@ import org.herac.tuxguitar.io.gp.GPFormatException;
 import org.herac.tuxguitar.song.models.BendEffect;
 import org.herac.tuxguitar.song.models.Duration;
 import org.herac.tuxguitar.song.models.InstrumentString;
+import org.herac.tuxguitar.song.models.Marker;
 import org.herac.tuxguitar.song.models.Measure;
+import org.herac.tuxguitar.song.models.MeasureHeader;
 import org.herac.tuxguitar.song.models.Note;
 import org.herac.tuxguitar.song.models.NoteEffect;
 import org.herac.tuxguitar.song.models.Song;
@@ -21,7 +23,7 @@ import org.herac.tuxguitar.song.models.SongChannel;
 import org.herac.tuxguitar.song.models.SongTrack;
 import org.herac.tuxguitar.song.models.Tempo;
 import org.herac.tuxguitar.song.models.TimeSignature;
-import org.herac.tuxguitar.song.models.TrackColor;
+import org.herac.tuxguitar.song.models.RGBColor;
 
 public class GP5InputStream extends InputStream {
     private static final String supportedVersions[] = { "FICHIER GUITAR PRO v5.00" };
@@ -153,14 +155,14 @@ public class GP5InputStream extends InputStream {
         int numberOfMeasures = readInt();
         int numberOfTracks = readInt();
         
-        List measures = new ArrayList();
+        List headers = new ArrayList();
         if (numberOfMeasures > 0) {
             for (int i = 0; i < numberOfMeasures; i++) {
             	if(i > 0 ){
             		skipBytes(1);
             	}
-                Measure measure = createMeasure((i + 1),timeSignature);
-                measures.add(measure);
+                MeasureHeader header = createMeasureHeader((i + 1),timeSignature);
+                headers.add(header);
             }
         }
 
@@ -173,33 +175,22 @@ public class GP5InputStream extends InputStream {
         
         long nextMeasureStart = 1000;        
         for (int i = 0; i < numberOfMeasures; i++) {
-            Measure currMeasure = (Measure) measures.get(i);
-            Measure lastMeasure = null;
-            currMeasure.setStart(nextMeasureStart);
+            MeasureHeader currHeader = (MeasureHeader) headers.get(i);
+            Tempo tempo = new Tempo(tempoValue);
+            currHeader.setStart(nextMeasureStart);
             for (int j = 0; j < numberOfTracks; j++) {
                 SongTrack track = (SongTrack) tracks.get(j);
-                Measure measure = (Measure) currMeasure.clone();
-
-                Tempo tempo = new Tempo(tempoValue);
+                Measure measure = new Measure(currHeader,new ArrayList(),new ArrayList(),1,0);                
                 addMeasureComponents(track.getStrings(), measure, track.getMeasures(), tempo);
-                                                        
-                //checkeo que el tempo coincida
-                if(lastMeasure != null && lastMeasure.getTempo().getValue() != tempo.getValue()){
-                	measure.setTempo((Tempo)lastMeasure.getTempo().clone());      
-                }else{
-                	measure.setTempo(tempo);       
-                }
-                lastMeasure = measure;                            
-                
+                currHeader.setTempo(tempo);
                 track.getMeasures().add(measure);
                 skipBytes(1);
             }
-            nextMeasureStart += currMeasure.getLength();
-            
-
+            tempoValue = tempo.getValue();
+            nextMeasureStart += currHeader.getLength();            
         }
-
-        return new Song(title,interpret,album,songAuthor,tracks,Song.MAX_VOLUME);
+        
+        return new Song(title,interpret,album,songAuthor,tracks,headers,Song.MAX_VOLUME);
     }
 
     private long addNotes(long start, List notes, List trackStrings, List currTrackMeasures, Tempo tempo) throws IOException,
@@ -297,25 +288,25 @@ public class GP5InputStream extends InputStream {
 
     private List getPlayedStrings(int stringsPlayed, List trackStrings) {
         List strings = new ArrayList();
-        if ((stringsPlayed & (1 << 0)) != 0) {
+        if ((stringsPlayed & (1 << 0)) != 0 && trackStrings.size() > 6) {
             strings.add(((InstrumentString) trackStrings.get(6)).clone());
         }
-        if ((stringsPlayed & (1 << 1)) != 0) {
+        if ((stringsPlayed & (1 << 1)) != 0 && trackStrings.size() > 5) {
             strings.add(((InstrumentString) trackStrings.get(5)).clone());
         }
-        if ((stringsPlayed & (1 << 2)) != 0) {
+        if ((stringsPlayed & (1 << 2)) != 0 && trackStrings.size() > 4) {
             strings.add(((InstrumentString) trackStrings.get(4)).clone());
         }
-        if ((stringsPlayed & (1 << 3)) != 0) {
+        if ((stringsPlayed & (1 << 3)) != 0 && trackStrings.size() > 3) {
             strings.add(((InstrumentString) trackStrings.get(3)).clone());
         }
-        if ((stringsPlayed & (1 << 4)) != 0) {
+        if ((stringsPlayed & (1 << 4)) != 0 && trackStrings.size() > 2) {
             strings.add(((InstrumentString) trackStrings.get(2)).clone());
         }
-        if ((stringsPlayed & (1 << 5)) != 0) {
+        if ((stringsPlayed & (1 << 5)) != 0 && trackStrings.size() > 1) {
             strings.add(((InstrumentString) trackStrings.get(1)).clone());
         }
-        if ((stringsPlayed & (1 << 6)) != 0) {
+        if ((stringsPlayed & (1 << 6)) != 0 && trackStrings.size() > 0) {
             strings.add(((InstrumentString) trackStrings.get(0)).clone());
         }
         return strings;
@@ -346,6 +337,10 @@ public class GP5InputStream extends InputStream {
             duration = new Duration(Duration.SIXTY_FOURTH);
             break;
         }
+        if(duration == null){
+        	duration = new Duration(Duration.QUARTER);
+        	System.err.println("Incorrect Duration. Forcing duration Quarter as Default.");
+        }        
         return duration;
     }
 
@@ -380,13 +375,13 @@ public class GP5InputStream extends InputStream {
         return (byte) read();
     }
 
-    private TrackColor readColor() throws IOException {
+    private RGBColor readColor() throws IOException {
         int r = readUnsignedByte();
         int g = readUnsignedByte();
         int b = readUnsignedByte();
         read();
         
-        return new TrackColor(r,g,b);
+        return new RGBColor(r,g,b);
     }
 
     private int readInt() throws IOException {
@@ -398,13 +393,15 @@ public class GP5InputStream extends InputStream {
 
         return integer;
     }
-
-    private void readMarker() throws IOException {
+    
+    private Marker readMarker(int measure) throws IOException {
         String name = readStringIntegerPlusOne();
-        readColor();
-    }
+        RGBColor color = readColor();
+        
+        return new Marker(measure,name,color);
+    }    
 
-    private Measure createMeasure(int number,TimeSignature currTimeSignature) throws IOException {
+    private MeasureHeader createMeasureHeader(int number,TimeSignature currTimeSignature) throws IOException {
         int header = readUnsignedByte();
 
         int numerator = 0;
@@ -424,9 +421,10 @@ public class GP5InputStream extends InputStream {
             numberOfRepetitions = readByte();
         }
 
+        Marker marker = null;
         if ((header & 0x20) != 0) {
-            readMarker();
-        }
+        	marker = readMarker(number);
+        }        
         
         int NumberOfAlternateEnding = 0;
         if ((header & 0x10) != 0) {
@@ -453,14 +451,21 @@ public class GP5InputStream extends InputStream {
         //--------------------------------
         if(NumberOfAlternateEnding == 0){
         	skipBytes(1);	
-        }        
-        skipBytes(1);
+        }                
         
         if ((header & 0x01) != 0) {
         	skipBytes(4);          	
         }        
         
-        return new Measure(number,0, new ArrayList(), new ArrayList(), (TimeSignature) currTimeSignature.clone(), new Tempo(120),1,0, repeatStart,numberOfRepetitions);
+        int tripletFeel = MeasureHeader.TRIPLET_FEEL_NONE;
+        int gpTripletFeel = readByte(); 
+        if(gpTripletFeel == 1){
+        	tripletFeel = MeasureHeader.TRIPLET_FEEL_EIGHTH;
+        }else if(gpTripletFeel == 2){
+        	tripletFeel = MeasureHeader.TRIPLET_FEEL_SIXTEENTH;
+        }
+        
+        return new MeasureHeader(number,0,(TimeSignature) currTimeSignature.clone(), new Tempo(120),marker,tripletFeel,repeatStart,numberOfRepetitions);
     }
 
     private void addMeasureComponents(List trackStrings, Measure measure, List currTrackMeasures, Tempo tempo) throws IOException,GPFormatException {
@@ -543,19 +548,18 @@ public class GP5InputStream extends InputStream {
     }
 
     private String readStringByte(int expectedLength) throws IOException {
-        byte[] b;
-        String str;
+        byte[] bytes;
         int realLength = readUnsignedByte();
 
         if (expectedLength != 0) {
-            b = new byte[expectedLength];
+        	bytes = new byte[expectedLength];
         } else {
-            b = new byte[realLength];
+        	bytes = new byte[realLength];
         }
-
-        read(b);
-        str = new String(b, 0, realLength);
-        return str;
+        read(bytes);
+        
+        realLength = (realLength >= 0)?realLength:expectedLength;
+        return new String(bytes, 0, realLength);  
     }
 
     private String readStringInteger() throws IOException {
@@ -622,11 +626,11 @@ public class GP5InputStream extends InputStream {
 
         int capo = readInt();
 
-        TrackColor color = readColor();
+        RGBColor color = readColor();
         
         skipBytes(44);
         
-        return new SongTrack(number,name,parseChannel(channels,channelIndex,effects), new ArrayList(), strings,color);
+        return new SongTrack(number,name,parseChannel(channels,channelIndex,effects), new ArrayList(), strings,0,color);
     }
     
     private SongChannel parseChannel(List channels, int channelIndex,int effectChannel) {
@@ -841,7 +845,7 @@ public class GP5InputStream extends InputStream {
             case 3:
                 break;
             default:
-                throw new IOException();
+                //throw new IOException();
             }
         }
 
@@ -922,6 +926,16 @@ public class GP5InputStream extends InputStream {
     		readByte();
     	}
     }
+    
+
+    private void skipBytes(int count,boolean debug) throws IOException{
+    	System.out.println("---------");
+    	for(int i = 0;i < count;i ++){
+    		int b = readByte();
+    		System.out.println(b);
+    	}
+    	System.out.println("---------");
+    }
 }
 class JoinVoicesHelper{
 	private Measure measure;
