@@ -6,10 +6,12 @@
  */
 package org.herac.tuxguitar.play.models;
 
+import java.io.File;
 import java.io.OutputStream;
 import java.util.List;
 
 import javax.sound.midi.Soundbank;
+import javax.sound.midi.Synthesizer;
 
 import org.herac.tuxguitar.song.models.SongChannel;
 import org.herac.tuxguitar.song.models.SongTrack;
@@ -29,12 +31,13 @@ public interface Player {
     public void reset();
     public boolean isPaused();
     public boolean isRunning();
-    public boolean isRealTimeSequencer();
+    public void setSynthesizer(Synthesizer synthesizer);
     public void playBeat(final SongTrack track,final List notes);
     public void updateChannels();
     public void updateChannel(SongChannel channel);
     public void setTickPosition(long position,long startMove);
     public long getTickPosition();
-    public Soundbank getDefaultSoundbank();
+    public Soundbank getSoundbank();
+    public boolean loadSoundbank(File file);
     public void write(OutputStream out);
 }
