@@ -11,6 +11,7 @@ import java.util.List;
 import javax.sound.midi.InvalidMidiDataException;
 import javax.sound.midi.MetaMessage;
 import javax.sound.midi.MidiEvent;
+import javax.sound.midi.MidiMessage;
 import javax.sound.midi.Sequence;
 import javax.sound.midi.ShortMessage;
 import javax.sound.midi.Track;
@@ -20,11 +21,13 @@ import org.herac.tuxguitar.song.models.BendEffect;
 import org.herac.tuxguitar.song.models.Duration;
 import org.herac.tuxguitar.song.models.InstrumentString;
 import org.herac.tuxguitar.song.models.Measure;
+import org.herac.tuxguitar.song.models.MeasureHeader;
 import org.herac.tuxguitar.song.models.Note;
 import org.herac.tuxguitar.song.models.SongChannel;
 import org.herac.tuxguitar.song.models.SongTrack;
 import org.herac.tuxguitar.song.models.Tempo;
 import org.herac.tuxguitar.song.models.TimeSignature;
+import org.herac.tuxguitar.song.models.Tupleto;
 
 /**
  * @author julian
@@ -44,13 +47,15 @@ public class SongSequence {
      */
     private SongManager songManager;
 
+    private int fisrtTickMove;
     
-    public SongSequence(SongManager songManager) {
+    public SongSequence(SongManager songManager,int fisrtTickMove) {
         this.songManager = songManager;
+        this.fisrtTickMove = fisrtTickMove;
     }
 
-    public void createSongSecuence(boolean muted,boolean metaMessages) {
-        this.createSecuence(muted,metaMessages);
+    public void createSongSecuence(boolean metaMessages) {
+        this.createSecuence(metaMessages);
     }
 
     public Sequence getSongSecuence() {
@@ -63,20 +68,16 @@ public class SongSequence {
     /**
      * Crea la cancion
      */        
-    private void createSecuence(boolean muted,boolean metaMessages) {
+    private void createSecuence(boolean metaMessages) {
         try {
         	sequence = new Sequence(Sequence.PPQ,(int)Duration.QUARTER_TIME);
 
             for (int trackIdx = 0; trackIdx < this.songManager.getSong().getTracks().size(); trackIdx++) {
                 SongTrack songTrack = (SongTrack) this.songManager.getSong().getTracks().get(trackIdx);
-                createTrack(songTrack,(trackIdx == 0),muted,metaMessages);
+                createTrack(songTrack,(trackIdx == 0),metaMessages);
             }                        
-            addTimeSignature(new TimeSignature(4, new Duration(Duration.QUARTER)), 0, sequence.getTracks()[0]);
-            addTempo(new Tempo(100), 0, sequence.getTracks()[0]);
-            if(muted){
-            	muteChannels();
-            }
-            
+            //addTimeSignature(new TimeSignature(4, new Duration(Duration.QUARTER)), 0, sequence.getTracks()[0]);
+            //addTempo(new Tempo(100), 1000, sequence.getTracks()[0]);            
         } catch (InvalidMidiDataException e) {
             e.printStackTrace();
         }
@@ -85,14 +86,13 @@ public class SongSequence {
     /**
      * Crea las pistas de la cancion
      */        
-    private void createTrack(SongTrack songTrack,boolean firstTrack,boolean muted,boolean metaMessages) {
+    private void createTrack(SongTrack songTrack,boolean firstTrack,boolean metaMessages) {
         try {
             Track midiTrack = sequence.createTrack();
             makeInstrument(midiTrack, songTrack.getChannel().getChannel(), songTrack.getChannel().getInstrument());            
-            addBend(midiTrack,0,DEFAULT_BEND,songTrack.getChannel().getChannel());   
-            if(!muted){
-            	setChannelValues(midiTrack,songTrack.getChannel());
-            }
+            addBend(midiTrack,Duration.QUARTER_TIME,DEFAULT_BEND,songTrack.getChannel().getChannel());               
+            setChannelValues(midiTrack,songTrack.getChannel());
+            
             //------controlo las repeticiones-------
             long repeatStart = 1000;
             boolean repeatOpen = true;
@@ -159,19 +159,25 @@ public class SongSequence {
         for (int noteIdx = 0; noteIdx < measure.getNotes().size(); noteIdx++) {
             Note note = (Note) measure.getNotes().get(noteIdx);
             if (!note.isTiedNote()) {
-                int key = note.getValue() + ((InstrumentString)songTrack.getStrings().get(note.getString() - 1)).getValue();
-                long start = note.getStart() + startMove;
-                long duration = getRealNoteDuration(note, songTrack.getMeasures(), measureIdx, noteIdx);
+                int key = songTrack.getOffset() + note.getValue() + ((InstrumentString)songTrack.getStrings().get(note.getString() - 1)).getValue();
+                
+                //long start = note.getStart() + startMove;
+                //long duration = getRealNoteDuration(note, songTrack.getMeasures(), measureIdx, noteIdx);
+                
+                NoteData data = checkTripletFeel(measure,note,noteIdx);
+                long start = data.start + startMove;
+                long duration = getRealNoteDuration(note,data.duration, songTrack.getMeasures(), measureIdx, noteIdx);
+                
                 int velocity = note.getVelocity();
                 int channel = songTrack.getChannel().getChannel();
                 
-                if(!songTrack.isPercusionTrack()){
+                if(!songTrack.isPercussionTrack()){
                     Note prevNote = getPrevNote(note,songTrack.getMeasures(),measureIdx,noteIdx);
                     if(prevNote != null && prevNote.getEffect().isHammer()){
                         velocity -= 25;
                     }
                 }
-                if(note.getEffect().hasEffects() && effectChannel >= 0 && !songTrack.isPercusionTrack()){              
+                if(note.getEffect().hasEffects() && effectChannel >= 0 && !songTrack.isPercussionTrack()){              
                     makeNote(midiTrack, key, start, duration, velocity,effectChannel);                    
                     if(note.getEffect().isBend()){
                         makeBend(midiTrack,start,duration,note.getEffect().getBend(),effectChannel);
@@ -200,9 +206,9 @@ public class SongSequence {
             messageOn.setMessage(ShortMessage.NOTE_ON, channel, key, velocity);
             messageOff.setMessage(ShortMessage.NOTE_OFF, channel, key, velocity);
 
-            track.add(new MidiEvent(messageOn, start));
-            track.add(new MidiEvent(messageOff, start + duration));
-
+            track.add(getMidiEvent(messageOn, start));
+            track.add(getMidiEvent(messageOff, start + duration));
+            
         } catch (InvalidMidiDataException e) {
             e.printStackTrace();
         }
@@ -214,9 +220,9 @@ public class SongSequence {
         		Track track = this.sequence.getTracks()[0];
         		for(int i = 0;i < SongManager.MAX_CHANNELS; i++){
         			ShortMessage message = new ShortMessage();
-        			message.setMessage(ShortMessage.CONTROL_CHANGE,i,DefinedControllers.BALANCE,64);
+        			//message.setMessage(ShortMessage.CONTROL_CHANGE,i,DefinedControllers.BALANCE,64);
         			message.setMessage(ShortMessage.CONTROL_CHANGE,i,DefinedControllers.VOLUME,0);
-        			track.add(new MidiEvent(message, 0));                   
+        			track.add(getMidiEvent(message,Duration.QUARTER_TIME));                   
         		}
         	}
         } catch (InvalidMidiDataException e) {
@@ -232,15 +238,15 @@ public class SongSequence {
         	
         	volume.setMessage(ShortMessage.CONTROL_CHANGE,channel.getChannel(),DefinedControllers.VOLUME,channel.getVolume());
         	balance.setMessage(ShortMessage.CONTROL_CHANGE,channel.getChannel(),DefinedControllers.BALANCE,channel.getBalance());        	
-        	track.add(new MidiEvent(volume,0));                   
-        	track.add(new MidiEvent(balance,0));
+        	track.add(getMidiEvent(volume,Duration.QUARTER_TIME));                   
+        	track.add(getMidiEvent(balance,Duration.QUARTER_TIME));
         	if(channel.getChannel() != channel.getEffectChannel()){
             	volume = new ShortMessage();
             	balance = new ShortMessage();        		
             	volume.setMessage(ShortMessage.CONTROL_CHANGE,channel.getEffectChannel(),DefinedControllers.VOLUME,channel.getVolume());
             	balance.setMessage(ShortMessage.CONTROL_CHANGE,channel.getEffectChannel(),DefinedControllers.BALANCE,channel.getBalance());        	
-            	track.add(new MidiEvent(volume,0));                   
-            	track.add(new MidiEvent(balance,0));        		        		
+            	track.add(getMidiEvent(volume,Duration.QUARTER_TIME));                   
+            	track.add(getMidiEvent(balance,Duration.QUARTER_TIME));        		        		
         	}
         	
         } catch (InvalidMidiDataException e) {
@@ -255,7 +261,7 @@ public class SongSequence {
         try {
             ShortMessage message = new ShortMessage();
             message.setMessage(ShortMessage.PROGRAM_CHANGE, channel, instrument, 0);
-            track.add(new MidiEvent(message, 0));
+            track.add(getMidiEvent(message,Duration.QUARTER_TIME));
         } catch (InvalidMidiDataException e) {
             e.printStackTrace();
             System.exit(1);
@@ -311,7 +317,7 @@ public class SongSequence {
         data[3] = 8;
         metaMessage.setMessage(0x58, data, 4);
 
-        MidiEvent midiEvent = new MidiEvent(metaMessage, tick);
+        MidiEvent midiEvent = getMidiEvent(metaMessage, tick);
         track.add(midiEvent);
     }
 
@@ -345,13 +351,38 @@ public class SongSequence {
         data[2] = (byte) ((usq) & 0x00FF);
         metaMessage.setMessage(0x51, data, 3);
 
-        MidiEvent midiEvent = new MidiEvent(metaMessage, tick);
+        MidiEvent midiEvent = getMidiEvent(metaMessage, tick);
         track.add(midiEvent);
     }
 
     /**
      * Retorna la Duracion real de una nota, verificando si tiene otras ligadas
      */
+    private long getRealNoteDuration(Note note,long duration, List measures, int measureIndex, int noteIndex) {
+    	if(note.getEffect().isDeadNote()){
+    		return DEFAULT_DEAD_NOTE_DURATION;
+    	}
+        //long duration = note.getDuration().getTime();
+        noteIndex++;
+        for (int mIdx = measureIndex; mIdx < measures.size(); mIdx++) {
+            Measure measure = (Measure) measures.get(mIdx);
+            for (int nIdx = noteIndex; nIdx < measure.getNotes().size(); nIdx++) {
+                Note nextNote = (Note) measure.getNotes().get(nIdx);
+                if (!nextNote.equals(note)) {
+                    if (nextNote.getString() == note.getString()) {
+                        if (nextNote.isTiedNote()) {
+                            duration += nextNote.getDuration().getTime();
+                        } else {
+                            return duration;
+                        }
+                    }
+                }
+            }
+            noteIndex = 0;
+        }
+        return duration;
+    }
+    /*
     private long getRealNoteDuration(Note note, List measures, int measureIndex, int noteIndex) {
     	if(note.getEffect().isDeadNote()){
     		return DEFAULT_DEAD_NOTE_DURATION;
@@ -377,14 +408,14 @@ public class SongSequence {
         return duration;
     }
 
-
+*/
     public void makeStartMoveMetaMessage(Track track, long start,long move) {        
         try {
             MetaMessage metaMessage = new MetaMessage();
             byte[] data = parseBytes(move);
             
             metaMessage.setMessage(MeasureStartMetaEventListener.START_MOVE, data, data.length);
-            MidiEvent event = new MidiEvent(metaMessage,start + move);
+            MidiEvent event = getMidiEvent(metaMessage,start + move);
             track.add(event);
         } catch (InvalidMidiDataException e) {
             e.printStackTrace();
@@ -412,7 +443,7 @@ public class SongSequence {
             ShortMessage bendMessage = new ShortMessage();                                    
             bendMessage.setMessage(ShortMessage.PITCH_BEND,channel,0, bend);
             
-            track.add(new MidiEvent(bendMessage, tick));            
+            track.add(getMidiEvent(bendMessage, tick));            
         } catch (InvalidMidiDataException e) {
             e.printStackTrace();
         }
@@ -500,6 +531,11 @@ public class SongSequence {
         }
     }
 
+    
+    private MidiEvent getMidiEvent(MidiMessage message,long tick){
+    	return new MidiEvent(message, tick + fisrtTickMove);    
+    }
+    
     private Note getNextNote(Note note,List measures, int measureIndex, int noteIndex){
         Note nextNote = null;    
         noteIndex ++;
@@ -547,4 +583,87 @@ public class SongSequence {
     
 
     
+    
+    private NoteData checkTripletFeel(Measure measure,Note note,int noteIndex){
+    	NoteData data = new NoteData();
+    	data.start = note.getStart();
+    	data.duration = note.getDuration().getTime();
+    	    	
+    	if(measure.getTripletFeel() == MeasureHeader.TRIPLET_FEEL_EIGHTH){
+    		if(note.getDuration().isEqual(new Duration(Duration.EIGHTH,false,false,Duration.NO_TUPLETO))){
+    			int time = (int)((Math.round((double)((double)note.getStart() / 10.00)) * 10) % 1000);
+    			//first time
+    			if(time == 0){
+    				Note next = getNextNote(note,measure,noteIndex);
+    				if(next != null && next.getDuration().isEqual(new Duration(Duration.EIGHTH,false,false,Duration.NO_TUPLETO))){
+    					data.duration = (new Duration(Duration.EIGHTH,false,false,new Tupleto(3,2)).getTime() * 2);
+    				}
+    			}
+    			//second time
+    			else if(time == (Duration.QUARTER_TIME / 2)){
+    				Note prev = getPrevNote(note,measure,noteIndex);
+    				if(prev != null && prev.getDuration().isEqual(new Duration(Duration.EIGHTH,false,false,Duration.NO_TUPLETO))){
+    					Duration duration = new Duration(Duration.EIGHTH,false,false,new Tupleto(3,2));
+    					data.start = prev.getStart() + (duration.getTime() * 2);
+    					data.duration = duration.getTime();
+    				}
+    			}    		
+    		}
+    	}else if(measure.getTripletFeel() == MeasureHeader.TRIPLET_FEEL_SIXTEENTH){
+    		if(note.getDuration().isEqual(new Duration(Duration.SIXTEENTH,false,false,Duration.NO_TUPLETO))){    	
+    			int time = (int)((Math.round((double)((double)note.getStart() / 10.00)) * 10) % 500);
+    			//first time
+    			if(time == 0){
+    				Note next = getNextNote(note,measure,noteIndex);
+    				if(next != null && next.getDuration().isEqual(new Duration(Duration.SIXTEENTH,false,false,Duration.NO_TUPLETO))){
+    					data.duration = (new Duration(Duration.SIXTEENTH,false,false,new Tupleto(3,2)).getTime() * 2);
+    				}
+    			}
+    			//second time
+    			else if(time == (Duration.QUARTER_TIME / 4)){
+    				Note prev = getPrevNote(note,measure,noteIndex);
+    				if(prev != null && prev.getDuration().isEqual(new Duration(Duration.SIXTEENTH,false,false,Duration.NO_TUPLETO))){
+    					Duration duration = new Duration(Duration.SIXTEENTH,false,false,new Tupleto(3,2));
+    					data.start = prev.getStart() + (duration.getTime() * 2);
+    					data.duration = duration.getTime();
+    				}
+    			}    		
+    		}
+    	}
+    	
+    	
+    	return data;
+    }
+    
+    private Note getPrevNote(Note note,Measure measure,int noteIndex){
+        Note prevNote = null;                
+        for (int nIdx = noteIndex - 1; nIdx >= 0; nIdx--) {
+        	Note currNote = (Note) measure.getNotes().get(nIdx);
+            if(currNote.getStart() < note.getStart()){
+            	if(prevNote == null || currNote.getStart() > prevNote.getStart()){
+            		prevNote = currNote;
+                }
+            }
+        }
+        
+        return prevNote;        
+    }
+    
+    private Note getNextNote(Note note,Measure measure,int noteIndex){
+        Note nextNote = null;                
+        for (int nIdx = noteIndex + 1; nIdx < measure.getNotes().size(); nIdx++) {
+        	Note currNote = (Note) measure.getNotes().get(nIdx);
+            if(currNote.getStart() > note.getStart()){
+            	if(nextNote == null || currNote.getStart() < nextNote.getStart()){
+            		nextNote = currNote;
+                }
+            }
+        }        
+        return nextNote;        
+    }
+    
+    private class NoteData{
+    	private long start;
+    	private long duration;    	
+    }
 }
\ No newline at end of file
